darkhistory.spec.transferfunclist
=================================

.. automodule:: darkhistory.spec.transferfunclist

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree: transferfunclist
   
      TransferFuncInterp
      TransferFuncInterps
      TransferFuncList
      TransferFuncListArray
   
   

   
   
   